emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] /srv/bzr/emacs/emacs-23 r100503: Fix spelling of "precede"


From: Glenn Morris
Subject: [Emacs-diffs] /srv/bzr/emacs/emacs-23 r100503: Fix spelling of "precede".
Date: Tue, 22 Feb 2011 23:08:12 -0800
User-agent: Bazaar (2.0.3)

------------------------------------------------------------
revno: 100503
committer: Glenn Morris <address@hidden>
branch nick: emacs-23
timestamp: Tue 2011-02-22 23:08:12 -0800
message:
  Fix spelling of "precede".
modified:
  lisp/allout.el
  lisp/cedet/semantic/analyze.el
  lisp/cedet/semantic/complete.el
  lisp/cedet/semantic/edit.el
  lisp/cedet/semantic/format.el
  lisp/cedet/semantic/java.el
  lisp/gnus/gnus-agent.el
  lisp/gnus/gnus-range.el
  lisp/gnus/gnus-start.el
  lisp/gnus/nntp.el
  lisp/mail/rmail.el
  lisp/net/tramp-gvfs.el
  lisp/obsolete/sym-comp.el
  lisp/progmodes/cperl-mode.el
  lisp/progmodes/idlwave.el
  lisp/progmodes/vhdl-mode.el
  lisp/replace.el
  lisp/textmodes/paragraphs.el
  src/w32proc.c
=== modified file 'lisp/allout.el'
--- a/lisp/allout.el    2011-01-02 23:50:46 +0000
+++ b/lisp/allout.el    2011-02-23 07:08:12 +0000
@@ -217,7 +217,7 @@
          -- positive numbers open to the relative depth indicated by the
             number, but do not force already opened subtopics to be closed.
          -- 0 means to close topic -- hide all subitems.
- :   -- repeat spec -- apply the preceeding element to all siblings at
+ :   -- repeat spec -- apply the preceding element to all siblings at
         current level, *up to* those siblings that would be covered by specs
         following the `:' on the list.  Ie, apply to all topics at level but
         trailing ones accounted for by trailing specs.  (Only the first of
@@ -3173,7 +3173,7 @@
                  nil)
         ;; rationale: if any intervening items were at a lower depth, we
         ;; would now be on the first offspring at the target depth -- ie,
-        ;; the preceeding item (per the search direction) must be at a
+        ;; the preceding item (per the search direction) must be at a
         ;; lesser depth.  that's all we need to check.
         (if backward (allout-next-heading) (allout-previous-heading))
         (if (< allout-recent-depth target-depth)
@@ -4276,7 +4276,7 @@
 
 With an argument greater than one, shift-in the item but not its
 offspring, making the item into a sibling of its former children,
-and a child of sibling that formerly preceeded it.
+and a child of sibling that formerly preceded it.
 
 You are not allowed to shift the first offspring of a topic
 inwards, because that would yield a \"containment
@@ -5394,7 +5394,7 @@
 
       (goto-char start)
       (beginning-of-line)
-      ;; Goto initial topic, and register preceeding stuff, if any:
+      ;; Goto initial topic, and register preceding stuff, if any:
       (if (> (allout-goto-prefix-doublechecked) start)
          ;; First topic follows beginning point -- register preliminary stuff:
          (setq result (list (list 0 "" nil

=== modified file 'lisp/cedet/semantic/analyze.el'
--- a/lisp/cedet/semantic/analyze.el    2011-01-02 23:50:46 +0000
+++ b/lisp/cedet/semantic/analyze.el    2011-02-23 07:08:12 +0000
@@ -101,7 +101,7 @@
           :type list
           :documentation "List of tags defining local text.
 This can be nil, or a list where the last element can be a string
-representing text that may be incomplete.  Preceeding elements
+representing text that may be incomplete.  Preceding elements
 must be semantic tags representing variables or functions
 called in a dereference sequence.")
    (prefixclass :initarg :prefixclass

=== modified file 'lisp/cedet/semantic/complete.el'
--- a/lisp/cedet/semantic/complete.el   2011-01-02 23:50:46 +0000
+++ b/lisp/cedet/semantic/complete.el   2011-02-23 07:08:12 +0000
@@ -1265,7 +1265,7 @@
 ;; generated by a collector.  This format is in semanticdb search
 ;; form.  This vaguely standard form is a bit challenging to navigate
 ;; because the tags do not contain buffer info, but the file associated
-;; with the tags preceed the tag in the list.
+;; with the tags precedes the tag in the list.
 ;;
 ;; Basic displayors don't care, and can strip the results.
 ;; Advanced highlighting displayors need to know when they need

=== modified file 'lisp/cedet/semantic/edit.el'
--- a/lisp/cedet/semantic/edit.el       2011-01-02 23:50:46 +0000
+++ b/lisp/cedet/semantic/edit.el       2011-02-23 07:08:12 +0000
@@ -427,7 +427,7 @@
            ;; confirmed as the lineage of `overlapped-tags'
            ;; which must have a value by now.
 
-           ;; Loop over the search list to find the preceeding CDR.
+           ;; Loop over the search list to find the preceding CDR.
            ;; Fortunatly, (car overlapped-tags) happens to be
            ;; the first tag positionally.
            (let ((tokstart (semantic-tag-start (car overlapped-tags))))
@@ -875,7 +875,7 @@
            ))
       (message "To Remove Middle Tag: (%s)"
               (semantic-format-tag-name first)))
-    ;; Find in the cache the preceeding tag
+    ;; Find in the cache the preceding tag
     (while (and cachestart (not (eq first (car (cdr cachestart)))))
       (setq cachestart (cdr cachestart)))
     ;; Find the last tag

=== modified file 'lisp/cedet/semantic/format.el'
--- a/lisp/cedet/semantic/format.el     2011-01-02 23:50:46 +0000
+++ b/lisp/cedet/semantic/format.el     2011-02-23 07:08:12 +0000
@@ -297,7 +297,7 @@
 
 (define-overloadable-function semantic-format-tag-canonical-name (tag 
&optional parent color)
   "Return a canonical name for TAG.
-A canonical name includes the names of any parents or namespaces preceeding
+A canonical name includes the names of any parents or namespaces preceding
 the tag.
 Optional argument PARENT is the parent type if TAG is a detail.
 Optional argument COLOR means highlight the prototype with font-lock colors.")

=== modified file 'lisp/cedet/semantic/java.el'
--- a/lisp/cedet/semantic/java.el       2011-01-02 23:50:46 +0000
+++ b/lisp/cedet/semantic/java.el       2011-02-23 07:08:12 +0000
@@ -257,7 +257,7 @@
 (define-mode-local-override semantic-documentation-for-tag
   java-mode (&optional tag nosnarf)
   "Find documentation from TAG and return it as a clean string.
-Java have documentation set in a comment preceeding TAG's definition.
+Java has documentation set in a comment preceding TAG's definition.
 Attempt to strip out comment syntactic sugar, unless optional argument
 NOSNARF is non-nil.
 If NOSNARF is 'lex, then return the semantic lex token."

=== modified file 'lisp/gnus/gnus-agent.el'
--- a/lisp/gnus/gnus-agent.el   2011-01-02 23:50:46 +0000
+++ b/lisp/gnus/gnus-agent.el   2011-02-23 07:08:12 +0000
@@ -444,7 +444,7 @@
                      (setf (gnus-agent-cat-groups old-category)
                            (delete group (gnus-agent-cat-groups
                                           old-category))))))
-               ;; Purge cache as preceeding loop invalidated it.
+               ;; Purge cache as preceding loop invalidated it.
                (setq gnus-category-group-cache nil))
 
              (setcdr (or (assq 'agent-groups category)
@@ -1202,7 +1202,7 @@
            (mapc #'gnus-summary-remove-process-mark
                  (gnus-sorted-ndifference gnus-newsgroup-processable 
gnus-newsgroup-undownloaded))
 
-            ;; The preceeding call to (gnus-agent-summary-fetch-group)
+            ;; The preceding call to (gnus-agent-summary-fetch-group)
             ;; updated the temporary gnus-newsgroup-downloadable to
             ;; remove each article successfully fetched.  Now, I
             ;; update the real gnus-newsgroup-downloadable to only
@@ -1527,14 +1527,14 @@
            header-number)
       ;; Check each article
       (while (setq article (pop articles))
-        ;; Skip alist entries preceeding this article
+        ;; Skip alist entries preceding this article
         (while (> article (or (caar alist) (1+ article)))
           (setq alist (cdr alist)))
 
         ;; Prune off articles that we have already fetched.
         (unless (and (eq article (caar alist))
                      (cdar alist))
-          ;; Skip headers preceeding this article
+          ;; Skip headers preceding this article
           (while (> article
                     (setq header-number
                           (let* ((header (car headers)))
@@ -3441,7 +3441,7 @@
 
                   ;; If considering all articles is set, I can only
                   ;; expire article IDs that are no longer in the
-                  ;; active range (That is, articles that preceed the
+                  ;; active range (That is, articles that precede the
                   ;; first article in the new alist).
                   (if (and gnus-agent-consider-all-articles
                            (>= article-number (car active)))
@@ -3718,7 +3718,7 @@
                   (gnus-agent-append-to-list tail-uncached v1))
                  (setq arts (cdr arts))
                  (setq ref (cdr ref)))
-                (t ; reference article (v2) preceeds the list being filtered
+                (t ; reference article (v2) precedes the list being filtered
                  (setq ref (cdr ref))))))
       (while arts
        (gnus-agent-append-to-list tail-uncached (pop arts)))
@@ -4022,7 +4022,7 @@
        ;; article (with the exception of the last ID in the list - it's
        ;; special) that no longer appears in the overview.  In this
        ;; situtation, the last article ID in the list implies that it,
-       ;; and every article ID preceeding it, have been fetched from the
+       ;; and every article ID preceding it, have been fetched from the
        ;; server.
 
        (if gnus-agent-consider-all-articles

=== modified file 'lisp/gnus/gnus-range.el'
--- a/lisp/gnus/gnus-start.el   2011-01-02 23:50:46 +0000
+++ b/lisp/gnus/gnus-start.el   2011-02-23 07:08:12 +0000
@@ -1582,7 +1582,7 @@
           (num 0))
 
       ;; These checks are present in gnus-activate-group but skipped
-      ;; due to setting dont-check in the preceeding call.
+      ;; due to setting dont-check in the preceding call.
 
       ;; If a cache is present, we may have to alter the active info.
       (when (and gnus-use-cache info)
@@ -1908,7 +1908,7 @@
                             ;; OK - I'm done
                             (setq articles nil))
                            ((< range article)
-                            ;; this range preceeds the article. Leave the 
range unmodified.
+                            ;; this range precedes the article. Leave the 
range unmodified.
                             (pop ranges)
                             ranges)
                            ((= range article)
@@ -1931,11 +1931,11 @@
                             (setcar ranges min)
                             ranges)
                            ((< max article)
-                            ;; this range preceeds the article. Leave the 
range unmodified.
+                            ;; this range precedes the article. Leave the 
range unmodified.
                             (pop ranges)
                             ranges)
                            ((< article min)
-                            ;; this article preceeds the range.  Return null 
to move to the
+                            ;; this article precedes the range.  Return null 
to move to the
                             ;; next article
                             nil)
                            (t

=== modified file 'lisp/gnus/nntp.el'
--- a/lisp/gnus/nntp.el 2011-01-02 23:50:46 +0000
+++ b/lisp/gnus/nntp.el 2011-02-23 07:08:12 +0000
@@ -1632,7 +1632,7 @@
 
         ;; Some nntp servers seem to have an extension to the XOVER
         ;; extension.  On these servers, requesting an article range
-        ;; preceeding the active range does not return an error as
+        ;; preceding the active range does not return an error as
         ;; specified in the RFC.  What we instead get is the NOV entry
         ;; for the first available article.  Obviously, a client can
         ;; use that entry to avoid making unnecessary requests.  The

=== modified file 'lisp/mail/rmail.el'
--- a/lisp/mail/rmail.el        2011-02-23 01:56:49 +0000
+++ b/lisp/mail/rmail.el        2011-02-23 07:08:12 +0000
@@ -514,7 +514,7 @@
 \"subject\" or \"from\".  A FIELD of \"to\" will automatically include
 all text from the \"cc\" field as well.
 
-REGEXP is an expression to match in the preceeding specified FIELD.
+REGEXP is an expression to match in the preceding specified FIELD.
 FIELD/REGEXP pairs continue in the list.
 
 examples:

=== modified file 'lisp/net/tramp-gvfs.el'
--- a/lisp/net/tramp-gvfs.el    2011-01-02 23:50:46 +0000
+++ b/lisp/net/tramp-gvfs.el    2011-02-23 07:08:12 +0000
@@ -139,7 +139,7 @@
         (add-to-list 'tramp-methods (cons elt nil))))))
 
 (defconst tramp-gvfs-path-tramp (concat dbus-path-emacs "/Tramp")
-  "The preceeding object path for own objects.")
+  "The preceding object path for own objects.")
 
 (defconst tramp-gvfs-service-daemon "org.gtk.vfs.Daemon"
   "The well known name of the GVFS daemon.")

=== modified file 'lisp/obsolete/sym-comp.el'
--- a/lisp/obsolete/sym-comp.el 2011-01-02 23:50:46 +0000
+++ b/lisp/obsolete/sym-comp.el 2011-02-23 07:08:12 +0000
@@ -51,7 +51,7 @@
 point."
   (save-restriction
     ;; Narrow in case point is in the middle of a symbol -- we want
-    ;; just the preceeding part.
+    ;; just the preceding part.
     (narrow-to-region (point-min) (point))
     (current-word)))
 

=== modified file 'lisp/progmodes/cperl-mode.el'
--- a/lisp/progmodes/idlwave.el 2011-01-02 23:50:46 +0000
+++ b/lisp/progmodes/idlwave.el 2011-02-23 07:08:12 +0000
@@ -429,7 +429,7 @@
 variable can be set to specify the paths where IDLWAVE can find PRO
 files.  The shell will only be asked for a list of paths when this
 variable is nil.  The value is a list of directories.  A directory
-preceeded by a `+' will be searched recursively.  If you set this
+preceded by a `+' will be searched recursively.  If you set this
 variable on a UNIX system, the shell will not be queried.  See also
 `idlwave-system-directory'."
   :group 'idlwave-routine-info
@@ -1198,7 +1198,7 @@
          (2 font-lock-function-name-face)))
 
        ;; Keyword parameters, like /xlog or ,xrange=[]
-       ;; This is anchored to the comma preceeding the keyword.
+       ;; This is anchored to the comma preceding the keyword.
        ;; Treats continuation lines, works only during whole buffer
        ;; fontification.  Slow, use it only in fancy fontification.
        (keyword-parameters

=== modified file 'lisp/progmodes/vhdl-mode.el'
--- a/lisp/progmodes/vhdl-mode.el       2011-01-02 23:50:46 +0000
+++ b/lisp/progmodes/vhdl-mode.el       2011-02-23 07:08:12 +0000
@@ -1792,7 +1792,7 @@
 
 (defcustom vhdl-intelligent-tab t
   "*Non-nil means `TAB' does indentation, word completion and tab insertion.
-That is, if preceeding character is part of a word then complete word,
+That is, if preceding character is part of a word then complete word,
 else if not at beginning of line then insert tab,
 else if last command was a `TAB' or `RET' then dedent one step,
 else indent current line (i.e. `TAB' is bound to `vhdl-electric-tab').
@@ -6974,7 +6974,7 @@
 ;; Indentation commands
 
 (defun vhdl-electric-tab (&optional prefix-arg)
-  "If preceeding character is part of a word or a paren then hippie-expand,
+  "If preceding character is part of a word or a paren then hippie-expand,
 else if right of non whitespace on line then insert tab,
 else if last command was a tab or return then dedent one step or if a comment
 toggle between normal indent and inline comment indent,
@@ -10440,7 +10440,7 @@
   (if vhdl-upper-case-keywords (upcase-word num) (downcase-word num)))
 
 (defun vhdl-minibuffer-tab (&optional prefix-arg)
-  "If preceeding character is part of a word or a paren then hippie-expand,
+  "If preceding character is part of a word or a paren then hippie-expand,
 else insert tab (used for word completion in VHDL minibuffer)."
   (interactive "P")
   (cond
@@ -13104,7 +13104,7 @@
 ;; Scan functions
 
 (defun vhdl-scan-context-clause ()
-  "Scan the context clause that preceeds a design unit."
+  "Scan the context clause that precedes a design unit."
   (let (lib-alist)
     (save-excursion
       (when (re-search-backward "^[ 
\t]*\\(architecture\\|configuration\\|entity\\|package\\)\\>" nil t)

=== modified file 'lisp/replace.el'
--- a/lisp/replace.el   2011-01-02 23:50:46 +0000
+++ b/lisp/replace.el   2011-02-23 07:08:12 +0000
@@ -1402,7 +1402,7 @@
 #&    (string-to-number (match-string 0))
 #     replace-count
 
-Note that these symbols must be preceeded by a backslash in order to
+Note that these symbols must be preceded by a backslash in order to
 type them using Lisp syntax."
   (while (consp n)
     (cond

=== modified file 'lisp/textmodes/paragraphs.el'
--- a/lisp/textmodes/paragraphs.el      2011-01-02 23:50:46 +0000
+++ b/lisp/textmodes/paragraphs.el      2011-02-23 07:08:12 +0000
@@ -43,7 +43,7 @@
 
 Prefix argument says to turn mode on if positive, off if negative.
 When the mode is turned on, if there are newlines in the buffer but no hard
-newlines, ask the user whether to mark as hard any newlines preceeding a
+newlines, ask the user whether to mark as hard any newlines preceding a
 `paragraph-start' line.  From a program, second arg INSERT specifies whether
 to do this; it can be `never' to change nothing, t or `always' to force
 marking, `guess' to try to do the right thing with no questions, nil

=== modified file 'src/w32proc.c'
--- a/src/w32proc.c     2011-01-02 23:50:46 +0000
+++ b/src/w32proc.c     2011-02-23 07:08:12 +0000
@@ -872,7 +872,7 @@
 
      Note that using backslash to escape embedded quotes requires
      additional special handling if an embedded quote is already
-     preceeded by backslash, or if an arg requiring quoting ends with
+     preceded by backslash, or if an arg requiring quoting ends with
      backslash.  In such cases, the run of escape characters needs to be
      doubled.  For consistency, we apply this special handling as long
      as the escape character is not quote.


reply via email to

[Prev in Thread] Current Thread [Next in Thread]
--- a/lisp/gnus/gnus-range.el   2011-01-02 23:50:46 +0000
+++ b/lisp/gnus/gnus-range.el   2011-02-23 07:08:12 +0000
@@ -87,10 +87,10 @@
                ;; All done with range2
                (setq r nil))
               ((< max1 min2)
                ;; No overlap: range1 preceeds range2
                (pop r))
               ((< max2 min1)
                ;; No overlap: range2 preceeds range1
                (pop range2))
               ((and (<= min2 min1) (<= max1 max2))
                ;; Complete overlap: range1 removed
@@ -187,7 +187,7 @@
 RANGE1 and RANGE2 have to be sorted over <."
   (let* (out
          (min1 (car range1))
-         (max1 (if (numberp min1) 
+         (max1 (if (numberp min1)
                    (if (numberp (cdr range1))
                        (prog1 (cdr range1)
                          (setq range1 nil)) min1)
@@ -196,17 +196,17 @@
          (min2 (car range2))
          (max2 (if (numberp min2)
                    (if (numberp (cdr range2))
-                       (prog1 (cdr range2) 
-                         (setq range2 nil)) min2) 
+                       (prog1 (cdr range2)
+                         (setq range2 nil)) min2)
                  (prog1 (cdr min2)
                    (setq min2 (car min2))))))
     (setq range1 (cdr range1)
           range2 (cdr range2))
     (while (and min1 min2)
-      (cond ((< max1 min2)              ; range1 preceeds range2
+      (cond ((< max1 min2)              ; range1 precedes range2
              (setq range1 (cdr range1)
                    min1 nil))
-            ((< max2 min1)              ; range2 preceeds range1
+            ((< max2 min1)              ; range2 precedes range1
              (setq range2 (cdr range2)
                    min2 nil))
             (t                     ; some sort of overlap is occurring
@@ -87,10 +87,10 @@
                (setq r nil))
               ((< max1 min2)
-               ;; No overlap: range1 preceeds range2
+               ;; No overlap: range1 precedes range2
                (pop r))
               ((< max2 min1)
@@ -87,10 +87,10 @@
                (pop r))
               ((< max2 min1)
-               ;; No overlap: range2 preceeds range1
+               ;; No overlap: range2 precedes range1
                (pop range2))
               ((and (<= min2 min1) (<= max1 max2))

=== modified file 'lisp/gnus/gnus-start.el'
--- a/lisp/progmodes/cperl-mode.el      2011-01-02 23:50:46 +0000
+++ b/lisp/progmodes/cperl-mode.el      2011-02-23 07:08:12 +0000
@@ -2770,7 +2770,7 @@
                  (goto-char (cperl-beginning-of-property p look-prop))
                  (beginning-of-line)
                  (setq pre-indent-point (point)))))
-         (goto-char pre-indent-point)  ; Orig line skipping preceeding pod/etc
+         (goto-char pre-indent-point)  ; Orig line skipping preceding pod/etc
          (let* ((case-fold-search nil)
                 (s-s (cperl-get-state (car parse-data) (nth 1 parse-data)))
                 (start (or (nth 2 parse-data) ; last complete sexp terminated
@@ -2797,8 +2797,8 @@
                          (cperl-1+ char-after-pos) 'indentable)
                         p (1+ (cperl-beginning-of-property
                                (point) 'indentable))
-                        is-block       ; misused for: preceeding line in REx
-                        (save-excursion ; Find preceeding line
+                        is-block       ; misused for: preceding line in REx
+                        (save-excursion ; Find preceding line
                           (cperl-backward-to-noncomment p)
                           (beginning-of-line)
                           (if (<= (point) p)
@@ -2814,10 +2814,10 @@
                         prop (parse-partial-sexp p char-after-pos))
                   (cond ((not delim)   ; End the REx, ignore is-block
                          (vector 'indentable 'terminator p is-block))
-                        (is-block      ; Indent w.r.t. preceeding line
+                        (is-block      ; Indent w.r.t. preceding line
                          (vector 'indentable 'cont-line char-after-pos
                                  is-block char-after p))
-                        (t             ; No preceeding line...
+                        (t             ; No preceding line...
                          (vector 'indentable 'first-line p))))
                  ((get-text-property char-after-pos 'REx-part2)
                   (vector 'REx-part2 (point)))
@@ -2898,7 +2898,7 @@
                         (cperl-backward-to-start-of-continued-exp 
containing-sexp))
                     (beginning-of-line)
                     (cperl-backward-to-noncomment containing-sexp))
                   ;; Now we get non-label preceeding the indent point
                   (if (not (or (eq (1- (point)) containing-sexp)
                                (memq (preceding-char)
                                      (append (if is-block " ;{" " ,;{") 
'(nil)))
@@ -4840,7 +4840,7 @@
 ;;; Moreover, one takes positive approach (looks for else,grep etc)
 ;;; another negative (looks for bless,tr etc)
 (defun cperl-after-block-p (lim &optional pre-block)
-  "Return true if the preceeding } (if PRE-BLOCK, following {) delimits a 
block.
+  "Return true if the preceding } (if PRE-BLOCK, following {) delimits a block.
 Would not look before LIM.  Assumes that LIM is a good place to begin a
 statement.  The kind of block we treat here is one after which a new
 statement would start; thus the block in ${func()} does not count."
@@ -4869,7 +4869,7 @@
                               (progn
                                 (forward-sexp -1)
                                 (looking-at "sub[ \t\n\f#]"))))))
-               ;; What preceeds is not word...  XXXX Last statement in sub???
+               ;; What precedes is not word...  XXXX Last statement in sub???
                (cperl-after-expr-p lim))))
       (error nil))))
 
@@ -2898,7 +2898,7 @@
                     (beginning-of-line)
                     (cperl-backward-to-noncomment containing-sexp))
-                  ;; Now we get non-label preceeding the indent point
+                  ;; Now we get non-label preceding the indent point
                   (if (not (or (eq (1- (point)) containing-sexp)
                                (memq (preceding-char)

=== modified file 'lisp/progmodes/idlwave.el'